# Copyright 2020 John Reese
# Licensed under the MIT license

"""
Generate changelogs based on tag messages and shortlogs
"""

from .__version__ import __version__
from .project import Project
from .tag import Tag

__author__ = "John Reese"
